# Neetils Package

## Description

This package is a collection of useful functions that I have created to make my life easier. I have decided to share them with the world in the hope that they will make your life easier too.